# Installation
pip install [pnu-basename](https://pypi.org/project/pnu-basename/)

# BASENAME(1), DIRNAME(1)
This repository includes 2 Unix commands in 1:
* [basename(1)](https://github.com/HubTou/basename/blob/main/BASENAME.1.md) - return filename or directory portion of pathname
* [dirname(1)](https://github.com/HubTou/basename/blob/main/DIRNAME.1.md) - return directory portion of pathname

